@@ -32,14 +32,11 @@ public:
   explicit MainWindow(QWidget *parent = 0);
   ~MainWindow();
 
-protected:
-  void closeEvent(QCloseEvent *event);
-
 protected slots:
   void saveSettings();
   void loadSettings();
-  void enableSilencing(bool enabled);
   void setProfileEvents();
+  void saveAndClose();
 
 private:
   QMaemo5ValueButton *from_button, *to_button;
